@@ -1,5 +1,5 @@
 package Statocles;
-our $VERSION = '0.080';
+our $VERSION = '0.081';
 # ABSTRACT: A static site generator
 
 # The currently-running site.
@@ -31,7 +31,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.080
+version 0.081
 
 =head1 SYNOPSIS
 
@@ -142,7 +142,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Doug Bell Ferenc Erki Joel Berger Kent Fredric tadegenban Vladimir Lettiev William Lindley
+=for stopwords Doug Bell Ferenc Erki Joel Berger Kent Fredric Konrad Bucheli tadegenban Vladimir Lettiev William Lindley
 
 =over 4
 
@@ -164,6 +164,10 @@ Kent Fredric <kentnl@cpan.org>
 
 =item *
 
+Konrad Bucheli <kb@open.ch>
+
+=item *
+
 tadegenban <tadegenban@gmail.com>
 
 =item *
