@@ -1,5 +1,5 @@
 package Statocles::App::Blog;
-our $VERSION = '0.080';
+our $VERSION = '0.081';
 # ABSTRACT: A blog application
 
 use Text::Unidecode;
@@ -505,6 +505,15 @@ around pages => sub {
         }
     }
 
+    for ( my $i = 0; $i < @post_pages; $i++ ) {
+
+        my $page = $post_pages[$i];
+        my $prev_page = $i ? $post_pages[$i-1] : undef;
+        my $next_page = $post_pages[$i+1];
+        $page->prev( $prev_page->path ) if $prev_page;
+        $page->next( $next_page->path ) if $next_page;
+    }
+
     # Cache the post pages for this build
     # XXX: This needs to be handled more intelligently with proper dependencies
     $self->_post_pages( \@post_pages );
@@ -639,7 +648,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.080
+version 0.081
 
 =head1 DESCRIPTION
 
