@@ -1,5 +1,5 @@
 package Statocles::Page::Document;
-our $VERSION = '0.080';
+our $VERSION = '0.081';
 # ABSTRACT: Render document objects into HTML
 
 use Statocles::Base 'Class';
@@ -242,6 +242,22 @@ around layout => sub {
     return $self->$orig( @args );
 };
 
+#pod =attr next
+#pod
+#pod The path to the next document if it is part of a list.
+#pod
+#pod =attr prev
+#pod
+#pod The path to the previous document if it is part of a list.
+#pod
+#pod =cut
+
+has [qw( next prev )] => (
+    is => 'rw',
+    isa => Path,
+    coerce => Path->coercion,
+);
+
 1;
 
 __END__
@@ -256,7 +272,7 @@ Statocles::Page::Document - Render document objects into HTML
 
 =head1 VERSION
 
-version 0.080
+version 0.081
 
 =head1 DESCRIPTION
 
@@ -292,6 +308,14 @@ most important attributes are:
 
 The C<data> hash for this page. Defaults to the C<data> attribute from the Document.
 
+=head2 next
+
+The path to the next document if it is part of a list.
+
+=head2 prev
+
+The path to the previous document if it is part of a list.
+
 =head1 METHODS
 
 =head2 content
